@@ -177,7 +177,6 @@ sub rel2abs{
 
 sub _all_refs_addr{
     my $c = shift;
-	return grep defined, map refaddr($_), @_;
     while(@_){
         my $item = shift;
         
@@ -204,7 +203,7 @@ sub _all_refs_addr{
 }
 sub ref_mem_safe{
     my $sub = shift;
-    my $count_to_execute = shift ||500;
+    my $count_to_execute = shift ||200;
     my $count_to_be_ok   = shift ||50;
     
     my $nu = -1;
@@ -213,21 +212,15 @@ sub ref_mem_safe{
     my $old_max =0;
     for my $round (1..$count_to_execute){
         my @seq = &$sub();
-		{
-			push @seq,(\my $b), [], {}, &$sub(),[],{},\my $a;
-			push @seq, \my $d, [ 'asdfa', {asdf=> 1}];
-			push @seq, \my $c, [ 'asdfa', {asdf=> 1, rrr=>[ asdf=>1]}];
-			push @seq, &$sub;
-		}
-        my $new_max = max ( _all_refs_addr( @seq , ));
+        #my $a   = {};
+        push @seq,(\my $b), [], {}, &$sub(),[],{},\my $a;
+        my $new_max = max ( _all_refs_addr( {}, @seq ,$a, ));
             if ($old_max<$new_max){
                 $old_max = $new_max;
                 $nu = -1;
             };
         ++$nu;
-        if ($nu > $count_to_be_ok) {
-			return $round ;
-		}
+        return $round if ($nu > $count_to_be_ok) ;
     }
     return 0;
 }
